==> nextcloud-18.0.7.tgz: nextcloud/lib/l10n/uk.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Не можу писати у каталог \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Зазвичай це можна виправити, надавши веб-серверу права на запис в теці конфігурації",
    "See %s" : "Переглянути %s",
    "Sample configuration detected" : "Виявлено приклад конфігурації",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Було виявлено, що приклад конфігурації було скопійовано. Це може нашкодити вашій системі та не підтримується. Будь ласка, зверніться до документації перед внесенням змін в файл config.php",
    "%1$s and %2$s" : "%1$s та %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s та %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s та %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s та %5$s",
    "PHP %s or higher is required." : "Необхідно PHP %s або вище",
    "PHP with a version lower than %s is required." : "Потрібна версія PHP нижче %s ",
    "The command line tool %s could not be found" : "Утиліту командного рядка %s не знайдено",
    "The library %s is not available." : "Бібліотека %s недоступна.",
    "Remote wipe started" : "Розпочато віддалене стирання",
    "Remote wipe finished" : "Віддалене стирання завершено",
    "Authentication" : "Автентифікація",
    "Unknown filetype" : "Невідомий тип файлу",
    "Invalid image" : "Невірне зображення",
    "today" : "сьогодні",
    "tomorrow" : "завтра",
    "yesterday" : "вчора",
    "_in %n day_::_in %n days_" : ["через %n день","через %n дні","через %n днів","через %n днів"],
    "_%n day ago_::_%n days ago_" : ["%n день тому","%n днів тому","%n днів тому","%n днів тому"],
    "next month" : "наступноого місяця",
    "last month" : "минулого місяця",
    "next year" : "наступного року",
    "last year" : "минулого року",
    "_%n year ago_::_%n years ago_" : ["%n рік тому","%n років тому","%n років тому","%n років тому"],
    "in a few seconds" : "через кілька секунд",
    "seconds ago" : "секунди тому",
    "Empty file" : "Порожній файл",
    "File name is a reserved word" : "Ім’я файлу є зарезервованим словом",
    "File name contains at least one invalid character" : "Ім’я файлу містить принаймні один некоректний символ",
    "File name is too long" : "Ім’я файлу занадто довге",
    "Dot files are not allowed" : "Файли які починаються з крапки не допустимі",
    "Empty filename is not allowed" : "Порожні імена файлів не допускаються",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Застосунок \"%s\" не може бути встановлений через те, що файл appinfo не може бути прочитано.",
    "__language_name__" : "Українська",
    "Help" : "Допомога",
    "Apps" : "Застосунки",
    "Settings" : "Налаштування",
    "Log out" : "Вихід",
    "Users" : "Користувачі",
    "Unknown user" : "Невідомий користувач",
    "Additional settings" : "Додаткові налаштування",
    "%s enter the database username and name." : "%s введіть назву бази даних та ім'я користувача.",
    "%s enter the database username." : "%s введіть ім'я користувача бази даних.",
    "%s enter the database name." : "%s введіть назву бази даних.",
    "%s you may not use dots in the database name" : "%s не можна використовувати крапки в назві бази даних",
    "Oracle connection could not be established" : "Не можемо з'єднатися з Oracle ",
    "Oracle username and/or password not valid" : "Oracle ім'я користувача та/або пароль не дійсні",
    "PostgreSQL username and/or password not valid" : "PostgreSQL ім'я користувача та/або пароль не дійсні",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X не підтримується і %s не буде коректно працювати на цій платформі. Випробовуєте на свій риск!",
    "For the best results, please consider using a GNU/Linux server instead." : "Для кращих результатів розгляньте можливість використання GNU/Linux серверу",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Здається що екземпляр цього %s працює в 32-бітному PHP середовищі і open_basedir повинен бути налаштований в php.ini. Це призведе до проблем з файлами більше 4 ГБ і це дуже не рекомендується.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Будь ласка, вилучіть параметр open_basedir у вашому php.ini або перейдіть на 64-бітний PHP.",
    "Set an admin username." : "Встановіть ім'я адміністратора.",
    "Set an admin password." : "Встановіть пароль адміністратора.",
    "Can't create or write into the data directory %s" : "Неможливо створити або записати каталог даних %s",
    "Invalid Federated Cloud ID" : "Неправильний Об'єднаний Хмарний Ідентіфікатор ",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Бекенд спільного доступу %s повинен реалізовувати інтерфейс OCP\\Share_Backend",
    "Sharing backend %s not found" : "Бекенд спільного доступу %s не знайдено",
    "Sharing backend for %s not found" : "Бекенд спільного доступу для %s не знайдено",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s надав доступ »%2$s« та хоче додати:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s надав доступ »%2$s« та хоче додати",
    "»%s« added a note to a file shared with you" : "»%s« додав нотатку до опублікованого файлу",
    "Open »%s«" : "Відкрити 1%s",
    "%1$s via %2$s" : "%1$s через %2$s",
    "You are not allowed to share %s" : "Вам заборонено поширювати %s",
    "Expiration date is in the past" : "Дата закінчення в минулому",
    "%1$s shared »%2$s« with you" : "%1$s надав доступ до »%2$s«",
    "%1$s shared »%2$s« with you." : "%1$s надав доступ до »%2$s«.",
    "Click the button below to open it." : "Щоб відкрити файл, натисніть кнопку нижче.",
    "Could not find category \"%s\"" : "Не вдалося знайти категорію \"%s\"",
    "Sunday" : "Неділя",
    "Monday" : "Понеділок",
    "Tuesday" : "Вівторок",
    "Wednesday" : "Середа",
    "Thursday" : "Четвер",
    "Friday" : "П'ятниця",
    "Saturday" : "Субота",
    "Sun." : "Нд.",
    "Mon." : "Пн.",
    "Tue." : "Вт.",
    "Wed." : "Ср.",
    "Thu." : "Чт.",
    "Fri." : "Пт.",
    "Sat." : "Сб.",
    "Su" : "Нд.",
    "Mo" : "Пн.",
    "Tu" : "Вт.",
    "We" : "Ср.",
    "Th" : "Чт.",
    "Fr" : "Пт.",
    "Sa" : "Сб.",
    "January" : "Січень",
    "February" : "Лютий",
    "March" : "Березень",
    "April" : "Квітень",
    "May" : "Травень",
    "June" : "Червень",
    "July" : "Липень",
    "August" : "Серпень",
    "September" : "Вересень",
    "October" : "Жовтень",
    "November" : "Листопад",
    "December" : "Грудень",
    "Jan." : "Січ.",
    "Feb." : "Лют.",
    "Mar." : "Бер.",
    "Apr." : "Кві.",
    "May." : "Тра.",
    "Jun." : "Чер.",
    "Jul." : "Лип.",
    "Aug." : "Сер.",
    "Sep." : "Вер.",
    "Oct." : "Жов.",
    "Nov." : "Лис.",
    "Dec." : "Гру.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Тільки такі символи допускаються в імені користувача: \"a-z\", \"A-Z\", \"0-9\", і \"_.@-'\"",
    "A valid username must be provided" : "Потрібно задати вірне ім'я користувача",
    "Username contains whitespace at the beginning or at the end" : "Ім'я користувача містить символ пробілу в початку або в кінці",
    "A valid password must be provided" : "Потрібно задати вірний пароль",
    "The username is already being used" : "Ім'я користувача вже використовується",
    "User disabled" : "Користувач виключений",
    "Login canceled by app" : "Вхід скасовано застосунком",
    "a safe home for all your data" : "безпечний дім для ваших даних",
    "File is currently busy, please try again later" : "Файл на разі зайнятий, будь ласка, спробуйте пізніше",
    "Can't read file" : "Не можливо прочитати файл",
    "Application is not enabled" : "Застосунок не увімкнено",
    "Authentication error" : "Помилка автентифікації",
    "Token expired. Please reload page." : "Строк дії токена скінчився. Будь ласка, перезавантажте сторінку.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Не встановлено драйвер бази даних (sqlite, mysql, or postgresql).",
    "Cannot write into \"config\" directory" : "Не можу писати у теку \"config\"",
    "Cannot write into \"apps\" directory" : "Не можу писати у теку \"apps\"",
    "Cannot create \"data\" directory" : "Неможливо створити каталог даних",
    "Setting locale to %s failed" : "Установка локалі %s не вдалася",
    "Please install one of these locales on your system and restart your webserver." : "Встановіть один із цих мовних пакетів в вашу систему і перезапустіть веб-сервер.",
    "PHP module %s not installed." : "%s модуль PHP не встановлено.",
    "Please ask your server administrator to install the module." : "Будь ласка, зверніться до адміністратора, щоб встановити модуль.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Параметр PHP \"%s\" не встановлено в \"%s\".",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload налаштовано як \"%s\" замість очікуваного значення \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Для виправлення змініть <code>mbstring.func_overload</code> на <code>0</code> у вашому php.ini",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Необхідно libxml2 версії принаймні 2.7.0. На разі встановлена %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "Що виправити це оновіть версію libxml2 та перезапустіть веб-сервер.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Схоже, що PHP налаштовано на вичищення блоків вбудованої документації. Це зробить кілька основних додатків недоступними.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Це, ймовірно, обумовлено використанням кеша/прискорювача такого як Zend OPcache або eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Модулі PHP були встановлені, але вони все ще перераховані як відсутні?",
    "Please ask your server administrator to restart the web server." : "Будь ласка, зверніться до адміністратора, щоб перезавантажити сервер.",
    "PostgreSQL >= 9 required" : "Потрібно PostgreSQL> = 9",
    "Please upgrade your database version" : "Оновіть версію бази даних",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Змініть права доступу на 0770, щоб інші користувачі не могли отримати список файлів цього каталогу.",
    "Check the value of \"datadirectory\" in your configuration" : "Перевірте значення \"datadirectory\" у своїй конфігурації",
    "Your data directory is invalid" : "Ваш каталог даних недійсний",
    "Could not obtain lock type %d on \"%s\"." : "Не вдалося отримати блокування типу %d для \"%s\"",
    "Storage unauthorized. %s" : "Сховище не авторизовано. %s",
    "Storage incomplete configuration. %s" : "Неповна конфігурація сховища. %s",
    "Storage connection error. %s" : "Помилка з'єднання зі сховищем. %s",
    "Storage is temporarily not available" : "Сховище тимчасово недоступне",
    "Storage connection timeout. %s" : "Час під'єднання до сховища вичерпався. %s",
    "Following databases are supported: %s" : "Підтримуються наступні сервери баз даних: %s",
    "Following platforms are supported: %s" : "Підтримуються наступні платформи: %s",
    "Overview" : "Огляд",
    "Basic settings" : "Основні налаштування",
    "Sharing" : "Спільне",
    "Security" : "Безпека",
    "Groupware" : "Робочі групи",
    "Personal info" : "Особиста інформація",
    "Mobile & desktop" : "Смартфон та ноутбук"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-19.0.7.tgz: nextcloud/lib/l10n/uk.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Не можу писати у каталог \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Зазвичай це можна виправити, надавши веб-серверу права на запис в теці конфігурації",
    "See %s" : "Переглянути %s",
    "Sample configuration detected" : "Виявлено приклад конфігурації",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Було виявлено, що приклад конфігурації було скопійовано. Це може нашкодити вашій системі та не підтримується. Будь ласка, зверніться до документації перед внесенням змін в файл config.php",
    "%1$s and %2$s" : "%1$s та %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s та %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s та %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s та %5$s",
    "PHP %s or higher is required." : "Необхідно PHP %s або вище",
    "PHP with a version lower than %s is required." : "Потрібна версія PHP нижче %s ",
    "The command line tool %s could not be found" : "Утиліту командного рядка %s не знайдено",
    "The library %s is not available." : "Бібліотека %s недоступна.",
    "Remote wipe started" : "Розпочато віддалене стирання",
    "Remote wipe finished" : "Віддалене стирання завершено",
    "Authentication" : "Автентифікація",
    "Unknown filetype" : "Невідомий тип файлу",
    "Invalid image" : "Невірне зображення",
    "today" : "сьогодні",
    "tomorrow" : "завтра",
    "yesterday" : "вчора",
    "_in %n day_::_in %n days_" : ["через %n день","через %n дні","через %n днів","через %n днів"],
    "_%n day ago_::_%n days ago_" : ["%n день тому","%n днів тому","%n днів тому","%n днів тому"],
    "next month" : "наступноого місяця",
    "last month" : "минулого місяця",
    "next year" : "наступного року",
    "last year" : "минулого року",
    "_%n year ago_::_%n years ago_" : ["%n рік тому","%n років тому","%n років тому","%n років тому"],
    "in a few seconds" : "через кілька секунд",
    "seconds ago" : "секунди тому",
    "Empty file" : "Порожній файл",
    "File name is a reserved word" : "Ім’я файлу є зарезервованим словом",
    "File name contains at least one invalid character" : "Ім’я файлу містить принаймні один некоректний символ",
    "File name is too long" : "Ім’я файлу занадто довге",
    "Dot files are not allowed" : "Файли які починаються з крапки не допустимі",
    "Empty filename is not allowed" : "Порожні імена файлів не допускаються",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Застосунок \"%s\" не може бути встановлений через те, що файл appinfo не може бути прочитано.",
    "__language_name__" : "Українська",
    "Help" : "Допомога",
    "Apps" : "Застосунки",
    "Settings" : "Налаштування",
    "Log out" : "Вихід",
    "Users" : "Користувачі",
    "Unknown user" : "Невідомий користувач",
    "Additional settings" : "Додаткові налаштування",
    "%s enter the database username and name." : "%s введіть назву бази даних та ім'я користувача.",
    "%s enter the database username." : "%s введіть ім'я користувача бази даних.",
    "%s enter the database name." : "%s введіть назву бази даних.",
    "%s you may not use dots in the database name" : "%s не можна використовувати крапки в назві бази даних",
    "Oracle connection could not be established" : "Не можемо з'єднатися з Oracle ",
    "Oracle username and/or password not valid" : "Oracle ім'я користувача та/або пароль не дійсні",
    "PostgreSQL username and/or password not valid" : "PostgreSQL ім'я користувача та/або пароль не дійсні",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X не підтримується і %s не буде коректно працювати на цій платформі. Випробовуєте на свій риск!",
    "For the best results, please consider using a GNU/Linux server instead." : "Для кращих результатів розгляньте можливість використання GNU/Linux серверу",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Здається що екземпляр цього %s працює в 32-бітному PHP середовищі і open_basedir повинен бути налаштований в php.ini. Це призведе до проблем з файлами більше 4 ГБ і це дуже не рекомендується.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Будь ласка, вилучіть параметр open_basedir у вашому php.ini або перейдіть на 64-бітний PHP.",
    "Set an admin username." : "Встановіть ім'я адміністратора.",
    "Set an admin password." : "Встановіть пароль адміністратора.",
    "Can't create or write into the data directory %s" : "Неможливо створити або записати каталог даних %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Бекенд спільного доступу %s повинен реалізовувати інтерфейс OCP\\Share_Backend",
    "Sharing backend %s not found" : "Бекенд спільного доступу %s не знайдено",
    "Sharing backend for %s not found" : "Бекенд спільного доступу для %s не знайдено",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s надав доступ »%2$s« та хоче додати:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s надав доступ »%2$s« та хоче додати",
    "»%s« added a note to a file shared with you" : "»%s« додав нотатку до опублікованого файлу",
    "Open »%s«" : "Відкрити 1%s",
    "%1$s via %2$s" : "%1$s через %2$s",
    "You are not allowed to share %s" : "Вам заборонено поширювати %s",
    "Expiration date is in the past" : "Дата закінчення в минулому",
    "%1$s shared »%2$s« with you" : "%1$s надав доступ до »%2$s«",
    "%1$s shared »%2$s« with you." : "%1$s надав доступ до »%2$s«.",
    "Click the button below to open it." : "Щоб відкрити файл, натисніть кнопку нижче.",
    "Could not find category \"%s\"" : "Не вдалося знайти категорію \"%s\"",
    "Sunday" : "Неділя",
    "Monday" : "Понеділок",
    "Tuesday" : "Вівторок",
    "Wednesday" : "Середа",
    "Thursday" : "Четвер",
    "Friday" : "П'ятниця",
    "Saturday" : "Субота",
    "Sun." : "Нд.",
    "Mon." : "Пн.",
    "Tue." : "Вт.",
    "Wed." : "Ср.",
    "Thu." : "Чт.",
    "Fri." : "Пт.",
    "Sat." : "Сб.",
    "Su" : "Нд.",
    "Mo" : "Пн.",
    "Tu" : "Вт.",
    "We" : "Ср.",
    "Th" : "Чт.",
    "Fr" : "Пт.",
    "Sa" : "Сб.",
    "January" : "Січень",
    "February" : "Лютий",
    "March" : "Березень",
    "April" : "Квітень",
    "May" : "Травень",
    "June" : "Червень",
    "July" : "Липень",
    "August" : "Серпень",
    "September" : "Вересень",
    "October" : "Жовтень",
    "November" : "Листопад",
    "December" : "Грудень",
    "Jan." : "Січ.",
    "Feb." : "Лют.",
    "Mar." : "Бер.",
    "Apr." : "Кві.",
    "May." : "Тра.",
    "Jun." : "Чер.",
    "Jul." : "Лип.",
    "Aug." : "Сер.",
    "Sep." : "Вер.",
    "Oct." : "Жов.",
    "Nov." : "Лис.",
    "Dec." : "Гру.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Тільки такі символи допускаються в імені користувача: \"a-z\", \"A-Z\", \"0-9\", і \"_.@-'\"",
    "A valid username must be provided" : "Потрібно задати вірне ім'я користувача",
    "Username contains whitespace at the beginning or at the end" : "Ім'я користувача містить символ пробілу в початку або в кінці",
    "A valid password must be provided" : "Потрібно задати вірний пароль",
    "The username is already being used" : "Ім'я користувача вже використовується",
    "User disabled" : "Користувач виключений",
    "Login canceled by app" : "Вхід скасовано застосунком",
    "a safe home for all your data" : "безпечний дім для ваших даних",
    "File is currently busy, please try again later" : "Файл на разі зайнятий, будь ласка, спробуйте пізніше",
    "Can't read file" : "Не можливо прочитати файл",
    "Application is not enabled" : "Застосунок не увімкнено",
    "Authentication error" : "Помилка автентифікації",
    "Token expired. Please reload page." : "Строк дії токена скінчився. Будь ласка, перезавантажте сторінку.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Не встановлено драйвер бази даних (sqlite, mysql, or postgresql).",
    "Cannot write into \"config\" directory" : "Не можу писати у теку \"config\"",
    "Cannot write into \"apps\" directory" : "Не можу писати у теку \"apps\"",
    "Cannot create \"data\" directory" : "Неможливо створити каталог даних",
    "Setting locale to %s failed" : "Установка локалі %s не вдалася",
    "Please install one of these locales on your system and restart your webserver." : "Встановіть один із цих мовних пакетів в вашу систему і перезапустіть веб-сервер.",
    "PHP module %s not installed." : "%s модуль PHP не встановлено.",
    "Please ask your server administrator to install the module." : "Будь ласка, зверніться до адміністратора, щоб встановити модуль.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Параметр PHP \"%s\" не встановлено в \"%s\".",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload налаштовано як \"%s\" замість очікуваного значення \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Для виправлення змініть <code>mbstring.func_overload</code> на <code>0</code> у вашому php.ini",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Необхідно libxml2 версії принаймні 2.7.0. На разі встановлена %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "Що виправити це оновіть версію libxml2 та перезапустіть веб-сервер.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Схоже, що PHP налаштовано на вичищення блоків вбудованої документації. Це зробить кілька основних додатків недоступними.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Це, ймовірно, обумовлено використанням кеша/прискорювача такого як Zend OPcache або eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Модулі PHP були встановлені, але вони все ще перераховані як відсутні?",
    "Please ask your server administrator to restart the web server." : "Будь ласка, зверніться до адміністратора, щоб перезавантажити сервер.",
    "PostgreSQL >= 9 required" : "Потрібно PostgreSQL> = 9",
    "Please upgrade your database version" : "Оновіть версію бази даних",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Змініть права доступу на 0770, щоб інші користувачі не могли отримати список файлів цього каталогу.",
    "Check the value of \"datadirectory\" in your configuration" : "Перевірте значення \"datadirectory\" у своїй конфігурації",
    "Your data directory is invalid" : "Ваш каталог даних недійсний",
    "Could not obtain lock type %d on \"%s\"." : "Не вдалося отримати блокування типу %d для \"%s\"",
    "Storage unauthorized. %s" : "Сховище не авторизовано. %s",
    "Storage incomplete configuration. %s" : "Неповна конфігурація сховища. %s",
    "Storage connection error. %s" : "Помилка з'єднання зі сховищем. %s",
    "Storage is temporarily not available" : "Сховище тимчасово недоступне",
    "Storage connection timeout. %s" : "Час під'єднання до сховища вичерпався. %s",
    "Following databases are supported: %s" : "Підтримуються наступні сервери баз даних: %s",
    "Following platforms are supported: %s" : "Підтримуються наступні платформи: %s",
    "Overview" : "Огляд",
    "Basic settings" : "Основні налаштування",
    "Sharing" : "Спільне",
    "Security" : "Безпека",
    "Groupware" : "Робочі групи",
    "Personal info" : "Особиста інформація",
    "Mobile & desktop" : "Смартфон та ноутбук",
    "Invalid Federated Cloud ID" : "Неправильний Об'єднаний Хмарний Ідентіфікатор "
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
